function createNoiseFile(filename, mode, varargin)
%SETINJECTIONBLOCK - Sets the initial parameters of a injection block. 
%Sets the initial parameters for one instance of the injection block from
%Acme library. 
%
% Syntax: createNoiseFile(filename, block, mode, varargin)
%         createNoiseFile(filename, block, 'FromWorkspace', workspaceVarName)
%         createNoiseFile(filename, block, 'FromTimeFunction', funcHandle, t_timeseries)
%         createNoiseFile(filename, block, 'FromASD', funcHandle, freqs, N, enbw)
%
% Inputs:
%    mode - Specifies how the Injection signal is defined. 
%    'FromWorkspace': will use a timeseries existing on the base workspace;
%    'FromFunction': passes a function of time and a timeseries
%    argument;
%    'FromASD': passes a ASD, function of frequency and create a time series using
%    the ENBW algorithm; 
%    'FromFile': uses the data stored in a file.
%    workspaceVarName - name of the variable in the workspace, string;
%    funcHandle - function (either of t or f). Function handle;
%    t_timeseries - time part of a timeseries to be used as argument;
%    freqs - array containing [fMin, fMax, fSample].
%    N = number of points that the freqs array has;
%    filename - name of the file containing the data
%
% See also: createFrequencyArray, createTimeseriesFromASD_ENBW
%
% Author: Arthur Reis
% email: arthur.reis@aei.mpg.de
% Jun 2022; 


if strcmp(mode,'FromWorkspace')
    % varargin:
    % model, block, mode, workspaceVarName
    var = varargin{1};
    eval(strcat('save(filename,''var'',''-v7.3'');'));
      
elseif strcmp(mode,'FromFunction')
    % varargin:
    % model, block, mode, funcHandle, t_timeseries
    func = varargin{1}; 
    tSeries = varargin{2};
    arr = timeseries(func(tSeries),tSeries);
    save(filename,'arr','-v7.3');
    
elseif strcmp(mode,'FromASD') 
    % varargin:
    % model, block, mode, funcHandle, freqs
    func = varargin{1}; 
    frequencies = varargin{2}; %[fMin, fMax, fSample]
    N = varargin{3};
    fSeries = createFrequencyArray(frequencies(2),0,N,'lin', 2,'reverse');
    enbw = varargin{4}; 
    arr = createTimeseriesFromASD_ENBW(func,fSeries, enbw);      
    save(filename,'arr','-v7.3');
end


end

