clear;
acme = AcmeSim('sgrs_12el_full_noise_model',1e2+1,1e2+1);


%% Accelerometer Parameters 
l = 0.03;
gap = 0.001;
elSides = [l, l, l];
density = 20099;
g = gap;
V_TM = 0.5;
Cf = 10e-12; %F
Kp = 10;
Ki = 0.0;
Kd = 0.2;
% Kp = 0
% Ki = 0
% Kd = 0
% %%
% % % If is drag-free:
% driverGain = 0;
% V_TM = 0.5;
% Vp = 0; %V polarizing 

% If is non-drag-free:1000
%driverGain = -1;
%V_TM = 0.5;
%Vp = 0; %V polarizing 

TM   = acme.addTestMass('TM',l,gap,'density',density);
%el  =      addElectrodeSF(obj, BlockName, Sides, pos0, V_DC, channels, V_ACs)
electrodeInit;
acme.checkBlocks;

%fCar = 1e5;
%% Noises
capdcbias = 0;
%CapNoiseASD = @(f) 1.854e-22 ./f + 5.0124e-19; %F/sqrt(hz)
% Capacitive Noise

VspASD = @(f) 30e-6*f.^0 + 0.7e-8*1./f; %V/sqrt(Hz) Pollack 2008
CapNoiseASD = @(f) 51e-9.*f.^0 + capdcbias; %F/sqrt(hz)
CPDnoiseASD = @(f) capXA.force_from_CPD(10e-3)*f.^0; %worst case 

CapNoiseTS = acme.noiseTS(CapNoiseASD); 
CPDnoiseTS = acme.noiseTS(CPDnoiseASD);

% Cf = 10e-12; %F

% Actuation Noise
p = 1e-5; %Pa
GasThermalNoiseASD = @(f) gasBrownianNoise(p,acme.T,TM.l.x,TM.gap.x).*f.^0 + TM.mass*1.6e-15./sqrt(f);
GasThermalNoiseTS = acme.noiseTS(GasThermalNoiseASD);

% Electrostatic Noise
e = 1.6e-19;
lambdaeff = 1100;
Sq = @(f) e*sqrt(2*lambdaeff)./(2*pi.*f);
Svc = @(f) 1e-6.*f.^0;
Svi = @(f) sqrt((8.8e-16).*f.^-2 + (2.73e-13).*f.^-1);
Qmax = 5e6;
x0 = 10e-6;
SxLPF = @(f) 3e-5.*(f.^2.*(f>1e-4) + (f<=1e-4).*1e-8);
Sx0 = @(f) 0.*f;
Vc = 1;       % V, common voltage,
Vi = 3e-3;    % V, stray voltage
Sa = electrostaticNoise(acme, TM, capXA, Qmax*e, Vi, Vc, SxLPF, Sq, Svc, Svi); % TO FIX

ElectrostaticNoiseASD = sum(Sa(1:end,:));
ElectrostaticNoiseTS  = acme.noiseTS(ElectrostaticNoiseASD);

% Low Frequency Noise % TO REMOVE
%LoFreqNoiseASD = @(f) 1e-18.*f.^-2; %arbitrary
%LoFreqNoiseTS  = acme.noiseTS(LoFreqNoiseASD);


sat = Satellite;
%sat.altitude = 450; %edit here if needed. These are the defaults for GFO
% sat.mass = 470
% sat.Cd = 2.25
% sat.area = 0.9
[a, v] = actuationRequirementSimplified(sat,TM,capXA);
Vx0 = 2*v;
%p = 1e-5; %Pa

ActuationNoiseASD = @(f) v * 1e-6*f.^0; %V/sqrt(hz)
ActuationNoiseTS  = acme.noiseTS(ActuationNoiseASD);


FNGGM = [1e-5 1.8e-4 1e-3]; 
%STterp = interp1(xData,ST,FNGGM);
TASH  = [7.82e-12 3.61e-11 1.16e-10]; %m/s2 K
DTASH = [2.8e-10  5.01e-11 1.07e-11];%m/s2 K
TFEEU = [4.60e-11 4.60e-11 4.6e-11];%m/s2 K
T = 293;
stbocon = 5.670374419e-8;
l = 0.03;
m = 0.54;
p = 1e-5;
c = 299792458;
%      General model:
ST = @(x) 0.001*x.^0+ 1.09e-10*x.^-2;

%        a =       0.001  (-0.01835, 0.02035)
%        b =    1.09e-10  (1.069e-10, 1.111e-10)
%ST = fitresult(xData);
Sa =((T^3 *16*l^2*stbocon)/(3*m*c) + (p*l^2)/ (2*m*T))  .* ST(acme.frequencies)
thermalStabilityNoiseASD = @(f) 7.0732e-11.*(0.001*f.^0+ 1.09e-10*f.^-2);
thermalStabilityNoiseTS  = acme.noiseTS(thermalStabilityNoiseASD);
% fitresult = 
% 

% %CapNoiseASD = @(f) 1.854e-22 ./f + 5.0124e-19; %F/sqrt(hz)
% CapNoiseASD = @(f) 51e-9.*f.^0; %F/sqrt(hz)
% CapNoiseTS  = acme.noiseTS(CapNoiseASD);
% 
% VspASD = @(f) 30e-6*f.^0 + 0.7e-8*1./f; %V/sqrt(Hz) Pollack 2008
% 
% CPDnoiseASD = @(f) cap1.force_from_CPD(10e-3)*f.^0; %worst case
% CPDnoiseTS = acme.noiseTS(CPDnoiseASD);
% Cf = 10e-12; %F
%%
%NoiseASD = @(f)  1e-8*f.^0;
%XNoiseTS = acme.noiseTS(NoiseASD);
%YNoiseTS = acme.noiseTS(NoiseASD);
%ZNoiseTS = acme.noiseTS(NoiseASD);
%NoiseASD = @(f)  1e-8*f.^0;
%RollNoiseTS  = acme.noiseTS(@(f)  1e-10*f.^0);
%PitchNoiseTS = acme.noiseTS(@(f)  1e-10*f.^0);
%YawNoiseTS   = acme.noiseTS(@(f)  1e-10*f.^0);

Ktranslational = 1e6;
%Ktranslational = 0;
Krot = -1e15;
%Krot = 0
%%
tic
mdlOutput = sim(acme.modelName)
toc
%%
io(2) = linio(strcat(acme.modelName,'/capSumX'),1,'output');
io(1) = linio(strcat(acme.modelName,'/Mux12'),1,'input');
readout2accTF = getTFresponse(acme.modelName, io, acme.frequencies); % 
%%
vq = interp1(mdlOutput.diffcapacitance.Time,mdlOutput.diffcapacitance.Data(:,1),acme.time);
%ts = mdlOutput.simout.Data;%(10000:end);
[axx,fxx] = flpsd('ts', vq, acme.flpsdOpts{:});
readout2accTF = getTFresponse(acme.modelName, io, fxx); 
r = readout2accTF(1,:)';
loglog(fxx, axx.*r )
%%
% NoiseBudget demo: free-running calibration 
  % Click on this annotation to run the following:  
 % mdl = 'OLvsCL';  
 % dof = 'OL displacement';  
  freq = logspace(-3, 1, 100);  
  [noises, sys] = nbFromSimulink(acme.modelName, freq, 'dof', 'x');  
  nb = nbGroupNoises(acme.modelName, noises, sys);  
  matlabNoisePlot(nb);  
  
%%

t = tiledlayout(3,2);

% Top plot
ax1 = nexttile;
plot(out.tout, out.forces.Data(:,1));
title(ax1, 'force X');
ylabel(ax1, 'N')

%ax1.YLim = [-1.5e-10 1.5e-10];

ax2 = nexttile;
plot(out.tout, out.torques.Data(:,1))
title(ax2, 'torque roll');
ylabel(ax2, 'Nm')
%ax2.YLim = [-1.5e-10 1.5e-10];

ax3 = nexttile;
plot(out.tout, out.forces.Data(:,2))
title(ax3, 'force y');
ylabel(ax3, 'N');
%ax3.YLim = [-1.5e-10 1.5e-10];
% Bottom plot
ax4 = nexttile;
plot(out.tout, out.torques.Data(:,2))
title(ax4, 'torque pitch');
ylabel(ax4, 'Nm');
%ax4.YLim = [-1.5e-10 1.5e-10];
ax5 = nexttile;
plot(out.tout, out.forces.Data(:,3))
title(ax5, 'force z');
ylabel(ax5, 'N');
xlabel(ax5, 's')
%ax5.YLim = [-1.5e-10 1.5e-10];
ax6 = nexttile;
plot(out.tout, out.torques.Data(:,3))
title(ax6, 'torque yaw');
ylabel(ax6, 'Nm');
xlabel(ax6, 's')
%ax6.YLim = [-1.5e-10 1.5e-10];

linkaxes([ax1,ax3,ax5],'x');
linkaxes([ax2,ax4,ax6],'x');
title(t,"Resulting forces and torques on the TM after 1nN step @ 10s in X axis");