%% ACME - Simplified Capacitive Sensor Simulator
% All references are from Alvarez's 2022 paper, unless otherwise noted.
% This model is calculated in the frequency range 1e-4 - 1Hz. Effects of the
% 100kHz injection signal are accounted for but the signal is not fully
% simulated.
% Only the dominant noise sources from the complete model are included
% Arthur Reis, 28.11.2022
clear;
%% 

%mdl = 'sgrs_capSensor';
%load_system(mdl);
%% Simulation parameters
% frequency and time
acme = AcmeSim('sgrs_capSensor');

%% Accelerometer Parameters
% TM
TM = acme.addTestMass(0.54,0.03,0.001,0.7,'');

% Capacitive sensing
nominal_cap = 3.9e-12;% F, capacitance between tm and elec. when dx = 0
fTypical = 1e-2; %Hz
Cf =  10e-12; %F feedback capacitor
%% Voltage Reference
Vd = 5; % Vpp
fDetection = 1e5; %Hz 
capAttenuation = 0.1; 


%% Amplifier
IA_BPF_gain = 40;
chargeAmpNoiseASD = @(f) 51e-9.*f.^0; %V/sqrtHz
chargeAmpNoiseTS  = [acme.t timeseriesFromASD(chargeAmpNoiseASD, ...
    acme.enbw, acme.fSample, acme.nSteps).Data];     
%% Noise Budget
% this uses the SimulinkNB toolbox.
% it doesn't run the simulation. Instead, it finds the transfer functions of the
% linearized model and plots the noise budged
[noises, sys] = nbFromSimulink(acme.mdl, acme.freqs, 'dof', 'x');  
nb = nbGroupNoises(acme.mdl, noises, sys);  
  
%% Time domain simulation
mdlOutput = sim(acme.mdl);    

%% Finding the transfer functions
% finding the transfer function between recorded signal and the signal we wish
% to measure
[axx,fxx] = flpsd( 'ts', mdlOutput.simout.Data,acme.lpsdopts{:});
io(1) = linio(strcat(acme.mdl,'/Gain1'),1,'input');
io(2) = linio(strcat(acme.mdl,'/IA_BPF'),1,'output');
readout2capTF = getTFresponse(acme.mdl, io, fxx); % TF between readout and Cap1
sensorTFexp = fit(fxx,readout2capTF, 'poly2')

%% Expression for the total noise ASD
% assuming ASD = A/f + B, where B is the high freq limit
x = nb.sumNoise.f';
y = nb.sumNoise.asd';
sensorASDexp = fit(x,y, fittype(str2func(['@(a, x) a./x + ' num2str(y(end))])))

%from time domain simulation
xsim = fxx;
ysim = axx./readout2capTF;
sensorASDexpsim = fit(xsim,ysim, fittype(...
    str2func(['@(a, x) a./x + ' num2str(ysim(end))])))

%% Plots
matlabNoisePlot(nb);  
xlabel('Frequency [Hz]');
ylabel('Measured capacitance [F]');
loglog(acme.freqs, sensorASDexp(acme.freqs),'b.', 'displayName', 'Fit from lin model');
loglog(acme.freqs, sensorASDexpsim(acme.freqs),'k.','displayName', 'Fit  from sim');
loglog(fxx, axx./readout2capTF,'k-','LineWidth',1,'DisplayName', ...
    'ASD from time domain simulation');

%% Finding the transfer functions
% lpsd 
[axxs,fxxs] = flpsd( 'ts', mdlOutput.simout1.Data, 'fs', fSample, 'Kdes', Kdes, 'Lmin', Lmin, ...
        'Jdes', Jdes, 'win', 'hanning', 'olap', olap, 'order', order,...
        'scale', 'ASD', 'LTPDAmode',false);