%% Example 01
% ACME Basics - Time domain simulation
% The first simulation models a test mass that is disturbed by an impulse.
% There is a controller that will try keep the TM centered.
% The simulation is discrete and has a fixed step of length acme_dt_fixedstep
% Considering just 1 translational DOF
clear;
acme = AcmeSim('ex_01_time_domain');
acme.initModel();
% load the simulink model.
%mdl = 'ex_01_time_domain';
%load_system(mdl);
%acme_dt_fixedstep = 0.01;
%stopTime = 10;

%% Setting the TM and control parameters
%TM = acme.createTestMass(0.5,0.03,1,'dblInt')
mass = 0.08; %kg
gap = 0.0003; %m
% To set the block, the setter searches for a block named "dblInt" on the
% simulink system. Be sure to avoid typos.
dblint = setDblIntTrans(mdl, 'dblInt', mass, gap); 

% the sensor, controller and actuator is represented by only a PID block with
% arbitrary and adequated gains:
Kp = 4;
Ki = 3;
Kd = 1;

% and the TM is impacted by an impulse of
forceGain = 1e-6; % N

%% Run the simulation
sim(mdl);  
open_system([mdl '/scopeAcc']);
open_system([mdl '/scopePos']);
 
%% Simulate again 
% other than an external input, we can also simulate a TM that begins out of
% equilibrium
forceGain = 0;
x0 = 0.00005; 
dx0 = 0;
dblint = setDblIntTrans(mdl, 'dblInt', mass, gap, x0, dx0);

sim(mdl);
open_system([mdl '/scopePos']);

