%% Example 03
% ACME Basics - Instantiation
% ACME can handle multiple copies of the same block on one system;
% it uses the block name to locate and initialize the right one 
clear;

mdl = 'ex_03_parametrization';
load_system(mdl);

fMin = 1e-4;
fMax = 1;
stopTime = 1/fMin; 
%
nSteps = 1e5;
tStep = stopTime/nSteps; 
fSample = 1/(stopTime/nSteps); 
N = stopTime/tStep;
acme_dt_fixedstep = tStep;
t = (0:tStep:(stopTime-tStep))';
enbw = 1/stopTime;
%% 
% each instance of the double integrator and the PID blocks will have different
% parameters
mass = [0.08, 0.1, 0.15];
gap = [3e-4, 5e-4, 9e-4];
Kp = [0.04, 0.05, 0.06];
Ki = [0.003, 0.003, 0.003];
Kd = [0.1, 0.1, 0.12];

for i = 1:3
    % the blocks should be carefully named, as the setting functions will use
    % that name
    setDblIntTrans(mdl, ['dblInt' num2str(i)], mass(i), gap(i));
    setPID(mdl, ['pid' num2str(i)], Kp(i), Ki(i), Kd(i));
end


% Consider the ASDs:
noisefunc1 = @(f) 1e-12 * f.^-1;
noisefunc2 = @(f) 1e-10 * (f.^2 + f.^0);
enbw = 1;
Kdes = 100;
olap = 30;
Jdes = 1000;
Lmin = 1; 
order = 2;
% define a "From Workspace" Block that reads the variable:
noise_ts1 = [t timeseriesFromASD(noisefunc1, enbw, fSample, nSteps).Data];
noise_ts2 = [t timeseriesFromASD(noisefunc2, enbw, fSample, nSteps).Data];

[axx,fxx] = flpsd( 'ts', noise_ts1(:,2), 'fs', fSample, 'Kdes', Kdes, 'Lmin', Lmin, ...
        'Jdes', Jdes, 'win', 'hanning', 'olap', olap, 'order', order,...
        'scale', 'ASD', 'LTPDAmode',true);
[axx2,fxx2] = flpsd( 'ts', noise_ts2(:,2), 'fs', fSample, 'Kdes', Kdes, 'Lmin', Lmin, ...
        'Jdes', Jdes, 'win', 'hanning', 'olap', olap, 'order', order,...
        'scale', 'ASD', 'LTPDAmode',true);
loglog(fxx,axx,fxx2,axx2);
legend('noise1 asd', 'noise2 asd');
%% Run
sim(mdl);  

open_system([mdl '/Scope1']);
open_system([mdl '/Scope2']);
open_system([mdl '/Scope3']);