% Electrostatic ACC Model 
% Following the Simplified Gravitational Reference Sensor model
% The S-GRS is a scaled-down version of the LPF GRS
% from: arXiv:2107.08545v1
% Author: Arthur Reis
% email: arthur.reis@aei.mpg.de
% last review: 29.11.2022
clear;
acme = AcmeSim('sgrs_acc');
acme.initModel;

% If is non-drag-free:
driverGain = -20;
V_TM = 0.5;
Vp = 0; %V polarizing 
Vx0 = 16; %V rms

% If is drag-free:
% driverGain = 0;
% V_TM = 0.5;
% Vp = 0; %V polarizing 
% Vx0 = 0; %V rms
 
tmgap = 1e-3*[1, 2, 4];
TM = acme.addTestMass(0.54,30e-3,tmgap(1),1,'dblInt',0.07);

fCar = 1e5;

% Plane capacitors, each formed by two electrodes
cap1 = setPlaneCapacitor(acme.mdl, 'planeCapacitor1',  acme.eps0); 
cap2 = setPlaneCapacitor(acme.mdl, 'planeCapacitor2',  acme.eps0); 
%CapNoiseASD = @(f) 1.854e-22 ./f + 5.0124e-19; %F/sqrt(hz)
CapNoiseASD = @(f) 51e-9.*f.^0; %F/sqrt(hz)
CapNoiseTS  = [acme.t timeseriesFromASD(CapNoiseASD, acme.enbw, acme.fSample, acme.nSteps).Data];     
Cf = 10e-12; %F
%Cf = 10e-12; %F
%getSGRSCapSensorASD(acme, TM,1e-12,Cf,40,51e-9)
ActuationNoiseASD = @(f) 20e-6.*f.^0; %V/sqrt(hz)
ActuationNoiseTS  = [acme.t timeseriesFromASD(ActuationNoiseASD, acme.enbw, acme.fSample, acme.nSteps).Data];     
io(2) = linio(strcat(acme.mdl,'/BPF'),1,'output');
io(1) = linio(strcat(acme.mdl,'/Gain1'),1,'input');
dof = 'x';  
% Control
Kp = 10;
Ki = 0.0;
Kd = 10;
mdlOutput = [];
vqs = [];
rd = {};
as = {};
fs = {};
nb = [];
%%
for i=1:3

    TM = acme.addTestMass(0.54,30e-3,tmgap(i),1,'dblInt',0.07);
    el1 = setElectrode(acme.mdl,'electrode1',TM.area.x,-(TM.l.x/2+TM.gap.x), 0, 0 ,fCar); %Cage left
    el2 = setElectrode(acme.mdl,'electrode2',TM.area.x,- TM.l.x/2       , 0, V_TM,fCar); %TM left
    el3 = setElectrode(acme.mdl,'electrode3',TM.area.x,+ TM.l.x/2       , 0, V_TM,fCar); %TM right
    el4 = setElectrode(acme.mdl,'electrode4',TM.area.x,+(TM.l.x/2+TM.gap.x), 0, 0 ,fCar); %Cage right

    
    p = 1e-5; %Pa
    gasThermalNoiseASD = @(f) gasBrownianNoise(p,acme.T,TM.l.x,TM.gap.x).*f.^0 + TM.mass*1.6e-15./sqrt(f);
    gasThermalNoiseTS = [acme.t timeseriesFromASD(gasThermalNoiseASD, acme.enbw, acme.fSample, acme.nSteps).Data];     
    mdlOutput = [mdlOutput sim(acme.mdl)];     % might not work for drag free

    
    [noises, sys] = nbFromSimulink(acme.mdl, acme.freqs, 'dof', dof);  
    nb = [nb nbGroupNoises(acme.mdl, noises, sys)];  
     vq = interp1(mdlOutput(i).simout.Time,mdlOutput(i).simout.Data,acme.t);
    vqs = [vqs interp1(mdlOutput(i).simout.Time,mdlOutput(i).simout.Data,acme.t)];
    
 % ts = [ts mdlOutput(i).simout.Data];%

    [axx,fxx] = flpsd('ts', vq, acme.lpsdopts{:});
    rd(end+1) = {getTFresponse(acme.mdl, io, fxx)}; % 
    as(end+1) = {axx};
    fs(end+1) = {fxx};
end

%%
    
    loglog(fs{1},as{1}./rd{1},'b', ...
           fs{2},as{2}./rd{2},'r',...
           fs{3},as{3}./rd{3},'g',...
           nb(1).f,nb(1).asd,'--b',...
           nb(2).f,nb(2).asd,'--r',...
           nb(3).f,nb(3).asd,'--g')
     
    legend('1mm gap (time domain simulation)', ...
           '2mm ', ...
           '4mm ', ...
           '1mm gap (freq domain model linearization)', ...
           '2mm',...
           '4mm')
    title('Acc asd gap parametrization')
    ylabel('m/s² sqrt(hz)')
    xlabel('frequency hz')
    xlim([1e-4 1e-1]);
    ylim([1e-15 1e-8]);