% Optical ACC Model 
% Using displacement noise from LPF (ARMANO 2022)
% Author: Arthur Reis
% email: arthur.reis@aei.mpg.de
% last review: 23.01.2023
clear;
acme = AcmeSim('sgrs_ifoacc',1000,1000);
%% Accelerometer Parameters 
TM = TestMass(30e-3,1e-3,'mass',0.54);
TM = TM.attachBlock('sgrs_acc','dblInt');

TM.mass = .60;
TM.updateBlock;

TM.mass = 0.54;
TM.updateBlock;
% If is non-drag-free:
% driverGain = -20;
% V_TM = 0.5;
% Vp = 0; %V polarizing 
% Vx0 = 16; %V rms

% If is drag-free:
driverGain = 0;
V_TM = 0.5;
Vp = 0; %V polarizing 
Vx0 = 0; %V rms


fCar = 1e5;
el1 = setElectrode(acme.mdl,'electrode1',TM.area.x,-(TM.l.x/2+TM.gap.x), 0, 0 ,fCar); %Cage left
el2 = setElectrode(acme.mdl,'electrode2',TM.area.x,- TM.l.x/2       , 0, V_TM,fCar); %TM left
el3 = setElectrode(acme.mdl,'electrode3',TM.area.x,+ TM.l.x/2       , 0, V_TM,fCar); %TM right
el4 = setElectrode(acme.mdl,'electrode4',TM.area.x,+(TM.l.x/2+TM.gap.x), 0, 0 ,fCar); %Cage right

% Plane capacitors, each formed by two electrodes
cap1 = setPlaneCapacitor(acme.mdl, 'planeCapacitor1',  acme.eps0); 
cap2 = setPlaneCapacitor(acme.mdl, 'planeCapacitor2',  acme.eps0); 
%%
%CapNoiseASD = @(f) 1.854e-22 ./f + 5.0124e-19; %F/sqrt(hz)
a = -10
b = a*.2
c = 0
ifoNoiseASD = @(f)  1e-10*exp(a*f.^2 + b*f.^f + c)% - 1e6.*f.^-2; %F/sqrt(hz)
loglog(acme.Frequencies,ifoNoiseASD(acme.Frequencies));
%%
CapNoiseTS  = [acme.t timeseriesFromASD(CapNoiseASD, acme.enbw, acme.fSample, acme.nSteps).Data];     

Cf = 10e-12; %F
getSGRSCapSensorASD(acme, TM,1e-12,Cf,40,51e-9)
ActuationNoiseASD = @(f) 20e-6.*f.^0; %V/sqrt(hz)
ActuationNoiseTS  = [acme.t timeseriesFromASD(ActuationNoiseASD, acme.enbw, acme.fSample, acme.nSteps).Data];     

p = 1e-5; %Pa
gasThermalNoiseASD = @(f) gasBrownianNoise(p,acme.T,TM.l.x,TM.gap.x).*f.^0 + TM.mass*1.6e-15./sqrt(f);
gasThermalNoiseTS = [acme.t timeseriesFromASD(gasThermalNoiseASD, acme.enbw, acme.fSample, acme.nSteps).Data];     

% Control
Kp = 10;
Ki = 0.0;
Kd = 10;


%%
mdlOutput = sim(acme.mdl);     % might not work for drag free
%%
vq = interp1(mdlOutput.simout.Time,mdlOutput.simout.Data,acme.t);
ts = mdlOutput.simout.Data;%(10000:end);

[axx,fxx] = flpsd('ts', vq, acme.lpsdopts{:});
io(2) = linio(strcat(acme.mdl,'/BPF'),1,'output');
io(1) = linio(strcat(acme.mdl,'/Gain1'),1,'input');
readout2accTF = getTFresponse(acme.mdl, io, fxx); % 

%%
dof = 'x';  
[noises, sys] = nbFromSimulink(acme.mdl, acme.freqs, 'dof', dof);  
nb = nbGroupNoises(acme.mdl, noises, sys);  
matlabNoisePlot(nb);  
loglog(fxx,axx./readout2accTF)
xlim([1e-4 1e-1]);
ylim([1e-15 1e-8]);
