function w = HFT(n)
%HFT Returns a high dynamic range flat top window.
%   HFT returns a high dynamic range flat top window as described by Heinzel
%   2002. HFT248D has 10 cosine terms and -248dB of attenuation on the sidelobe.
 w = nan(n,1);
 for i=1:n
     w(i) = 1                                - 1.985844164102*cos(1*2*pi*i/n)...
            + 1.791176438506*cos(2*2*pi*i/n) - 1.282075284005*cos(3*2*pi*i/n)...
            + 0.667777530266*cos(4*2*pi*i/n) - 0.240160796576 *cos(5*2*pi*i/n)...
            + 0.056656381764*cos(6*2*pi*i/n) - 0.008134974479*cos(7*2*pi*i/n)...
            + 0.000624544650*cos(8*2*pi*i/n) - 0.000019808998*cos(9*2*pi*i/n)...
            + 0.000000132974*cos(10*2*pi*i/n);
     if isnan(w(i))
         w(i) = 0;
     end
 end
 w = w./max(w);
end

