function name = maketexdoc(filename, F, varargin)

if nargin==0
    filename='*.m';
end

listefilename=dir(filename);
listefilename={listefilename.name};

if ~length(listefilename)
    error('No file match.');
end

for f=1:length(listefilename)
    nbrelink=0;
    filename=listefilename{f};
    [pathstr,name,ext] = fileparts(filename);
	
	if ~strcmp(ext,'.m')
        error([filename ' is not an M-file.']);
    end
    texfilename=fullfile(pathstr,[F '/'  name '.tex']);
    fid=fopen(texfilename,'w');
    if fid==-1
        error(['Can''t create ' texfilename]);
    end

	headfline=['\subsection{', name, '}',   newline, ...
			   '\label{sec:', name, '}', newline, ...
			   '\begin{markdown},...',   newline, ...
			   '#### Description'];
    fprintf(fid,'%s\n',headfline);
    
    helptext=help(filename);

    % suppress the 'overloaded ...' part (for Contents.m file)
    pover=strfind(helptext,'Overloaded');
    if length(pover),
        helptext=[helptext(1:(pover-1)) char(10)];
    end;

    firstchar=6;
    remhelptext=helptext; % initialize the remainder of the help text
    firstline = true;
    while length(remhelptext)
        %extracts the first line of the remainder of the help text:
        pnextenter=strfind(remhelptext,10); pnextenter=pnextenter(1);
        curline=remhelptext(1:(pnextenter-1)); % current line
		if contains(curline,'Documentation for') || contains(curline, 'Author:')
			break
		end
        % removes the < and > signs (confusion with html syntax):
        curline=strrep(curline,'<','&lt;');
        curline=strrep(curline,'>','&gt;');
		%curline=strrep(curline,'_','\_');
		a = strip(curline);
		if ~isempty(a) 
			if a(1) == '%'
				curline=strrep(curline,'%','####');
			end
		end
		makecode = 0;
		if contains(curline,'=') && contains(curline,'(') %then its possibly code
			makecode =1;
		end
		
        if firstline % the first line of the help text is the name of the function
            if ~strcmpi(name,'contents')
                [token,remline]=strtok(curline);    
            end;
            if ~strcmpi(name,'contents'),
                %fprintf(fid,'%s\n','### Description');
            end;
            %fprintf(fid,'%s\n','<code><pre>');
            firstline = false;
        else
            % removes the first white spaces:
            curline=[curline '           '];
            while ~isequal(curline(firstchar-1),' '),
                firstchar=firstchar-1; %
            end;
            curline=deblank(curline(firstchar:end));

            % detects the 'See Also' section  (v1.01)
            pseealso=strfind(lower(curline),'see also');
            if ((length(pseealso))&&(length(curline)>2)),
                pseealso=pseealso(1);
                curline=curline((pseealso+9):end);
                seealsotoken=strtok(curline);
                pp=strfind(curline,seealsotoken); pp=pp(1); % position of the first character of the "see also" words
                curline=curline(pp:end);
            end;
            
            % detects the 'Examples' line (v1.22)
            if length(curline)>=7,
                pexample=strfind(lower(curline(1:7)),'example');
                if length(pexample)
                    fprintf(fid,'%s\n','</pre>');

                    fprintf(fid,'%s\n','<pre>');
                    curline=curline(8:end);
                    psc=findstr(curline,':');
                    if length(psc)
                        curline=curline((psc(1)+1):end);
                    end;
                end;
            end;
            
            if makecode
			curline = ['`' curline '`']; 
			end
			remline=curline; % remainder of the current line
			
			while length(remline),
                %[token, newremline] = strtok(remline,' ,.;:!?()[]{}"''=+-*/'); % next word
				[token, newremline] = strtok(remline,' ,.;:!?()[]{}"''=+*/'); % next word
				%tokenpos = strfind(curline,token);
				whitesplit = strsplit(curline, ...
					{' ', ',', '.', ';', ':', '!', '?', '(', ')', '[', ']', '{', '}'}, ...
					'CollapseDelimiters', true);
				tokenidx = find(strcmp(whitesplit,token),1);
			   if length(token)
                    pnextword=strfind(remline,token); pnextword=pnextword(1); % position of the next word
                    fprintf(fid,'%s',remline(1:(pnextword-1))); % writes the characters before % changed v1.06
			        makelink=0;
					try
                    if length(whitesplit) >= 4 && tokenidx >2
						%if any(curline(tokenpos-2) == '*') & any(curline(tokenpos + length(token)+1) == '-')
							%makelink=-1;
			
					 	if any(whitesplit{tokenidx-1} == '*') && any(whitesplit{tokenidx + 1} == '-')
							makelink=-1;
						end
						
                    end
					end
                    if makelink==1
                        fprintf(fid,'%s',['<a href="' lower(token) '.html">' lower(token) '</a>']);
                        nbrelink=nbrelink+1;
                    elseif makelink==-1,
                        fprintf(fid,'%s',['`' lower(token) '`']);
                    else
                        fprintf(fid,'%s',token);   % no link for this word
                    end;
                else  % if no word found until the end of the line, simply writes the end of the line:
				%if makecode 
                 %   fprintf(fid,'%s',['`' remline '`']);
				%else
                    fprintf(fid,'%s',remline);
				%end
                end;
                remline=newremline;
            end;

    
            fprintf(fid,'%s\n',' '); % end of the line
        end;
        remhelptext=remhelptext((pnextenter+1):end); % new remainder
    end;
 
    %fprintf(fid,'%s\n','</pre></code>');  % end of "code" section

    fprintf(fid,'%s\n',' ');

    % foot of the html page:
    if any(strncmpi(varargin,'lastline',4)),
        lastline = varargin{1+find(strncmpi(varargin,'lastline',4),1,'last')};
      %  lastline = strrep(lastline,'\f',name);
      %  fprintf(fid,'%s\n',[lastline '<br>']);
    end;
    
    %fprintf(fid,'%s\n','<br>');
    if ~any(strncmpi(varargin,'noadver',4)),  % hidden option: 'noad'
        %fprintf(fid,'%s\n','<font size=-1>Help file generated by <a href="http://www.fast.u-psud.fr/~moisy/ml" target="_blank">makehtmldoc 1.22</a></font><br>');
    end;
    fprintf(fid,'%s\n','\end{markdown}');
    fclose(fid);

    % new v1.02
    if ~any(strncmpi(varargin,'quiet',1)),
     %   disp([name '.m --> ' name '.html  [' num2str(nbrelink) ' links]']);
    end;
end;
