function ts = createTimeseriesFromASD_ENBW(ASDFunc, freqs,enbw)
%CREATETIMESERIESFROMASD_ENBW returns a timeseries from the ASD of a noise
%   Returns a timeseries from the amplitude spectral density of a noise.
%   The output time series will have the ASD, and random phase.
%
% Syntax: ts = createTimeseriesFromASD_ENBW(ASDFunc, freqs)
%       
% Inputs: ASDFunc - function handle where the expression for the ASD is
%         defined;
%         freqs - frequency array, linearly spaced and in reverse order, as 
%         constructed from createFrequencyArray;
%
% Outputs: ts - timeseries containing the noise;
%
% See also: createFrequencyArray, setInjectionBlock 
%
% Author: Arthur Reis
% email: arthur.reis@aei.mpg.de
% Nov 2021; Last revision: 10.Nov.2021;    

    ASD = ASDFunc(freqs);
    PSD_dblsided = (ASD).^2/2;
%     if length(PSD_dblsided ) == 1
%         PSD_dblsided = PSD_dblsided *ones(size(freqs));
%     end
    PSD_dblsided(freqs==0) = 0;
    U_f = sqrt(PSD_dblsided').*sqrt(enbw/2);
    phi = rand(size(U_f))*2*pi;
    phi(freqs==0) = 0; 
    freq_domain = U_f.*exp(phi.*1i)*numel(U_f)*sqrt(2); 
    ts = timeseries(ifft(freq_domain,'symmetric'));  
    
end