func = @(f) 1e-5.*f.^-3 + 2e-2*f.^1;
fMin = 1e-4;
fSample = 1;
fMax = fSample/2;
frequencies = [fMin, fMax, fSample];
N = 1e5;
fSeries = createFrequencyArray(frequencies(2),0,N,'lin', 2,'reverse');
enbw = 1;
ts = createTimeseriesFromASD_ENBW(func,fSeries, enbw).Data;   
Kdes = 100;
olap = 30;
Jdes = 1000;
Lmin = 1; 
ap1 = ao(plist('type','tsdata','yvals', ts,'fs', fSample,'yunits','m','name','x'));
% parameters: ts, fs, Kdes, Lmin, Jdes, win, olap, order, scale
%% Compare implementations
order = 0;
[a_org,f_org] = fpsd('ts', ts, 'fs', fSample,'mask',[], 'win',...
                      'hanning', 'olap', olap, 'order', order,...
                      'scale', 'PSD');
 aoPSD2 = psd([ap1],plist('scale','psd','win','hanning','order',2));
 
 figure
 loglog(f_org, a_org, aoPSD2.x, aoPSD2.y);
 legend('fpsd', 'PSD from LTPDA');
 title('Comparison of PSD implementations')
 xlabel('F[Hz]') 
 ylabel('PSD [units^2/Hz]') 

%% comparison of detrending capabilities
ts = ts + ((1:length(ts))').^2;
y=ts;

ap1 = ao(plist('type','tsdata','yvals', y,'fs', fSample,'yunits','m','name','x'));
order = 1;
[a_org_1,f_org_1] = fpsd('ts', ts, 'fs', fSample,'mask',[], 'win',...
                      'hanning', 'olap', olap, 'order', order,...
                      'scale', 'PSD');

aoPSD2_1 = psd([ap1],plist('scale','psd','win','hanning','order',order));
order = 2;
[a_org_2,f_org_2] = fpsd('ts', ts, 'fs', fSample,'mask',[], 'win',...
                      'hanning', 'olap', olap, 'order', order,...
                      'scale', 'PSD');

aoPSD2_2 = psd([ap1],plist('scale','psd','win','hanning','order',order));
order = 0;
[a_org_0,f_org_0] = fpsd('ts', ts, 'fs', fSample,'mask',[], 'win',...
                      'hanning', 'olap', olap, 'order', order,...
                      'scale', 'PSD');

aoPSD2_0 = psd([ap1],plist('scale','psd','win','hanning','order',order));
    
figure

t = tiledlayout(2,1);
title(t,'Comparison of detrending capabilities - timeseries w/ quad bias')
ax1 = nexttile;
loglog(f_org_0, a_org_0, f_org_1, a_org_1, f_org_2, a_org_2);
legend('LTPDA remove mean', 'LTPDA remove linear', 'LTPDA remove quad');
ylabel('PSD [units^2/Hz]') 

ax2 = nexttile;
loglog(aoPSD2_0.x,aoPSD2_0.y,  aoPSD2_1.x, aoPSD2_1.y, aoPSD2_2.x, aoPSD2_2.y);
legend('fpsd remove mean', 'fpsd remove linear', 'fpsd remove quad');
xlabel('F[Hz]') 
ylabel('PSD [units^2/Hz]') 
linkaxes([ax1,ax2],'x');

%% comparison of scales (monochromatic signal)
order = -1;
ts = sqrt(2)*sin(1:10000)';  
ap1 = ao(plist('type','tsdata','yvals', ts,'fs', fSample,'yunits','m','name','x'));
Pflpsd = [];
Fflpsd = [];
Pltpda  = [];
Fltpda  = [];
scales = {'PSD','PS','ASD','AS'};
for s=1:4
[pp,ff] = fpsd('ts', ts, 'fs', fSample,'mask',[], 'win',...
                      'hanning', 'olap', olap, 'order', order,...
                      'scale', scales{s});  
ltpout = psd([ap1],plist('scale',scales{s},'win','hanning','order',order));  
    Pflpsd(:,s) = pp;
    Fflpsd(:,s) = ff;
    Pltpda(:,s) = ltpout.y;
    Fltpda(:,s) = ltpout.x;
end
    
    %%
figure

t = tiledlayout(2,2);
title(t,'Comparison of scaling capabilities (monochromatic)')

ax1 = nexttile;
title('PSD')
loglog(Fflpsd(:,1), Pflpsd(:,1),Fltpda(:,1), Pltpda(:,1));
legend('rewritten','ltpda');
ylabel('PSD [units^2/Hz]') 
xlabel('F[Hz]') 

ax2 = nexttile;
title('PS')
loglog(Fflpsd(:,2), Pflpsd(:,2),Fltpda(:,2), Pltpda(:,2));
legend('rewritten','ltpda');
ylabel('PS [units^2]') 
xlabel('F[Hz]') 

ax3 = nexttile;
title('ASD')
loglog(Fflpsd(:,3), Pflpsd(:,3),Fltpda(:,3), Pltpda(:,3));
legend('rewritten','ltpda');
ylabel('ASD [units/sqrt(Hz)]') 
xlabel('F[Hz]') 

ax4 = nexttile;

title('AS')
loglog(Fflpsd(:,4), Pflpsd(:,4),Fltpda(:,4), Pltpda(:,4));
legend('rewritten','ltpda');ylabel('AS [units]') 
xlabel('F[Hz]') 

%% comparison of scales broad spectrum signal
ts = createTimeseriesFromASD_ENBW(func,fSeries, enbw).Data;  
ap1 = ao(plist('type','tsdata','yvals', ts,'fs', fSample,'yunits','m','name','x'));
Pflpsd = [];
Fflpsd = [];
Pltpda  = [];
Fltpda  = [];
scales = {'PSD','PS','ASD','AS'};
for s=1:4
[pp,ff] = fpsd('ts', ts, 'fs', fSample,'mask',[], 'win',...
                      'hanning', 'olap', olap, 'order', order,...
                      'scale', scales{s});  
ltpout = psd([ap1],plist('scale',scales{s},'win','hanning','order',order));  
    Pflpsd(:,s) = pp;
    Fflpsd(:,s) = ff;
    Pltpda(:,s) = ltpout.y;
    Fltpda(:,s) = ltpout.x;
end
    
%%
figure

t = tiledlayout(2,2);
title(t,'Comparison of scaling capabilities (broad spec)')

ax1 = nexttile;
title('PSD')
loglog(Fflpsd(:,1), Pflpsd(:,1),Fltpda(:,1), Pltpda(:,1));
legend('rewritten','ltpda');
ylabel('PSD [units^2/Hz]') 
xlabel('F[Hz]') 

ax2 = nexttile;
title('PS')
loglog(Fflpsd(:,2), Pflpsd(:,2),Fltpda(:,2), Pltpda(:,2));
legend('rewritten','ltpda');
ylabel('PS [units^2]') 
xlabel('F[Hz]') 

ax3 = nexttile;
title('ASD')
loglog(Fflpsd(:,3), Pflpsd(:,3),Fltpda(:,3), Pltpda(:,3));
legend('rewritten','ltpda');
ylabel('ASD [units/sqrt(Hz)]') 
xlabel('F[Hz]') 

ax4 = nexttile;

title('AS')
loglog(Fflpsd(:,4), Pflpsd(:,4),Fltpda(:,4), Pltpda(:,4));
legend('rewritten','ltpda');
ylabel('AS [units]') 
xlabel('F[Hz]') 
