function invertedTFresponse = getInvertedTFresponse(mdl, io, freqs)
%GETINVERTEDTFRESPONSE returns the response of the inverted transfer function
%of the linearized model.
%   Returns the response of the inverted transfer function of the linearized
%   model. First, linearizes the model around the given input and output. Then,
%   it gets the frequency response of the linear TF. Lastly, this is inverted.
% Syntax: invertedTFresponse = getInvertedTFresponse(mdl, io, freqs)
%       
% Inputs: mdl - simulink model, string;
%         io - list of IO elements;
%         freqs - array of frequencies to respond to
%
% Outputs: invertedTFresponse - array containing the response, 
%             same size as the frequencies;
%
% See also: frd, linearize, linio
%
% Author: Arthur Reis
% email: arthur.reis@aei.mpg.de
% Nov 2021; Last revision: 19.Nov.2021;  
linearizedModel = linearize(mdl,io);
linMdlResponse = frd(linearizedModel, freqs, 'unit', 'Hz');
invertedTF = abs(squeeze(inv(linMdlResponse)));
invertedTFresponse = squeeze(invertedTF.ResponseData);
end

