function TFresponse = getTFresponse(mdl, io, freqs)
%GETTFRESPONSE returns the response of the transfer function
%of the linearized model.
%   Returns the response of the transfer function of the linearized
%   model. First, linearizes the model around the given input and output. Then,
%   it gets the frequency response of the linear TF. 
% Syntax: TFresponse = getTFresponse(mdl, io, freqs)
%       
% Inputs: mdl - simulink model, string;
%         io - list of IO elements;
%         freqs - array of frequencies to respond to
%
% Outputs: TFresponse - array containing the response, 
%             same size as the frequencies;
%
% See also: frd, linearize, linio, getInvertedTFresponse
%
% Author: Arthur Reis
% email: arthur.reis@aei.mpg.de
% Nov 2021; Last revision: 24.Nov.2021;  
linearizedModel = linearize(mdl,io);
linMdlResponse = frd(linearizedModel, freqs, 'unit', 'Hz');
TFresponse = squeeze(abs(linMdlResponse.ResponseData));
end

